import axios from 'axios'
import url from '@/plugins/routes'
const timeout = 20000

const state = {
  free_drink_list_config: [],
  free_drink_list_history: []
}

const mutations = {
  set_free_drink_list_config(state, data) {
    state.free_drink_list_config = data
  },
  set_free_drink_list_history(state, data) {
    data.forEach(item => {
      item.timestamp = new Date(
        item.timestamp.year,
        item.timestamp.month - 1,
        item.timestamp.day,
        item.timestamp.hour,
        item.timestamp.minute,
        item.timestamp.second
      )
    })
    state.free_drink_list_history = data
    state.free_drink_list_history.reverse()
  }
}

const actions = {
  async get_free_drink_list_config({ commit, dispatch, rootState }) {
    try {
      const response = await axios.get(url.freeDrinkListConfig, {
        headers: { Token: rootState.login.user.accessToken },
        timeout
      })
      commit('set_free_drink_list_config', response.data)
    } catch (e) {
      if (e.message == 'Network Error') {
        dispatch('connectionError/addError', null, { root: true })
      }
      if (e.response)
        if (e.response.status === 401) dispatch('logout', null, { root: true })
    }
  },
  async get_free_drink_list_history({ commit, dispatch, rootState }) {
    try {
      const response = await axios.get(url.freeDrinkListHistory, {
        headers: { Token: rootState.login.user.accessToken },
        timeout
      })
      commit('set_free_drink_list_history', response.data)
    } catch (e) {
      if (e.message == 'Network Error') {
        dispatch('connectionError/addError', null, { root: true })
      }
      if (e.response)
        if (e.response.status === 401) dispatch('logout', null, { root: true })
    }
  },
  async set_free_drink_list_history({ commit, dispatch, rootState }, data) {
    try {
      const response = await axios.post(
        url.freeDrinkListHistory,
        { ...data },
        {
          headers: { Token: rootState.login.user.accessToken },
          timeout
        }
      )
      commit('set_free_drink_list_history', response.data)
    } catch (e) {
      if (e.message == 'Network Error') {
        dispatch('connectionError/addError', null, { root: true })
      }
      if (e.response)
        if (e.response.status === 401) dispatch('logout', null, { root: true })
    }
  },
  async update_free_drink_list_history({ commit, dispatch, rootState }, data) {
    try {
      await axios.put(
        url.freeDrinkListHistory,
        { ...data },
        { headers: { Token: rootState.login.user.accessToken }, timeout }
      )
      commit('set_free_drink_list_history', data)
    } catch (e) {
      if (e.message == 'Network Error') {
        dispatch('connectionError/addError', null, { root: true })
      }
      if (e.response)
        if (e.response.status === 401) dispatch('logout', null, { root: true })
    }
  }
}

const getters = {
  free_drink_list_config(state) {
    return state.free_drink_list_config
  },
  free_drink_list_config_job(state) {
    return state.free_drink_list_config.filter(item => {
      console.log(item)
      return item.free_drink_types.find(drink_type => {
        return drink_type.id == 1
      })
    })
  },
  free_drink_list_config_workgroup(state) {
    return state.free_drink_list_config.filter(item => {
      return item.free_drink_types.find(drink_type => {
        return drink_type.id == 2
      })
    })
  },
  free_drink_list_config_band(state) {
    return state.free_drink_list_config.filter(item => {
      return item.free_drink_types.find(drink_type => {
        return drink_type.id == 3
      })
    })
  },
  free_drink_list_history(state) {
    return state.free_drink_list_history
  },
  free_drink_list_history_band(state) {
    return state.free_drink_list_history.filter(item => {
      return item.free_drink_type.id == 3
    })
  },
  free_drink_list_history_band_without_canceled(state) {
    return state.free_drink_list_history.filter(item => {
      return item.free_drink_type.id == 3 && !item.canceled
    })
  },
  free_drink_list_history_job_credit(state) {
    let jobDrinks = state.free_drink_list_history.filter(item => {
      return item.free_drink_type.id == 1 && !item.storno
    })
    let credit = 0
    jobDrinks.forEach(item => {
      credit += item.free_drink_config.price
    })
    return credit
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions,
  getters
}
